@@ -4,6 +4,7 @@
 #include <QDBusMessage>
 #include <QDebug>
 #include <QNetworkInterface>
+#include <QDBusInterface>
 
 #if 0
 #include <QNetworkConfigurationManager>
@@ -15,6 +16,15 @@
 WebAppNativeServices::WebAppNativeServices(QObject *parent) :
     QObject(parent)
 {
+    //m_icd = new QDBusInterface("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
+    //                           QDBusConnection::systemBus());
+
+    QDBusConnection::systemBus().connect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
+                                         "status_changed", this, SLOT(doNetworkStatusChanged(QString,QString,QString,QString)));
+
+    //connect()
+    //connect(m_icd, SIGNAL(status_changed(QString, QString, QString, QString)), this, SLOT(doNetworkStatusChanged(QString,QString,QString,QString)));
+
 }
 
 // window.nativeservices.exitAppView() in javascript
@@ -79,3 +89,10 @@ bool WebAppNativeServices::isOnline()
     qDebug() << "isOnline = " << online;
     return online;
 }
+
+void WebAppNativeServices::doNetworkStatusChanged(const QString& a1, const QString& a2, const QString& a3, const QString& a4)
+{
+    //qDebug() << "network " << a1 << " : " << a2 << " : " << a3 << " : " << a4;
+    emit networkStatusChanged(a1,a2,a3, a4);
+
+}
