@@ -10,6 +10,8 @@ using QtMobility::QNetworkSession;
 
 #endif
 
+class QDBusInterface;
+
 
 class WebAppNativeServices : public QObject
 {
@@ -19,12 +21,16 @@ public:
 
 signals:
 
+    void networkStatusChanged(QString, QString, QString, QString);
 public slots:
     void exitAppView();
     // initiates connection asynchronously
 
     void requestConnection();
 
+private slots:
+    void doNetworkStatusChanged(const QString& a1, const QString& a2, const QString& a3, const QString& a4);
+
 
 #if 0
     QtMobility::QNetworkSession::State networkState();
@@ -39,6 +45,8 @@ signals:
 private:
     QtMobility::QNetworkSession* m_session;
 #endif
+private:
+    QDBusInterface* m_icd;
 
 };
 
